@@ -17,14 +17,17 @@ clusCA <- function(data,nclus,ndim,nstart=100,smartStart=NULL,gamma = FALSE, see
   }
   else
     Z = data
+  
+
   n=nrow(Z)
   Q=ncol(Z)
   
-  Dzh=diag(as.vector(colSums(Z)^(.5))) 
-  Dzhi=pseudoinverse(Dzh)
-  #Dzhi= chol2inv(chol(Dzh))
+  Dz=diag(apply(Z,2,sum)) # Dz
+  Dzhi=pseudoinverse(Dz^(0.5)) # %Dz^-.5
+  
   MZ=scale(Z,scale=FALSE)
   MZD = MZ %*% Dzhi
+  
   if(!is.null(seed)) set.seed(seed)
   seed <- round(2^31 * runif(nstart, -1, 1))
   
@@ -46,47 +49,33 @@ clusCA <- function(data,nclus,ndim,nstart=100,smartStart=NULL,gamma = FALSE, see
     }else{
       randVec=smartStart
     }
-    
-   Zki=tab.disjonctif(randVec)
-
+    Zki=tab.disjonctif(randVec)
     Dk=t(Zki) %*% Zki
+     
     Dks=Dk^(.5)
-    #Dksi=pseudoinverse(Dks)
-    Dksi= chol2inv(chol(Dks))
-    DZkZD= sqrt(n/q)*Dksi%*% t(Zki) %*% MZD     # equation 6 on the paper
+    Dksi= pseudoinverse(Dks)#chol2inv(chol(Dks))
+    #sqrt(n/q)
+    DZkZD= Dksi%*% t(Zki) %*% MZD     # equation 6 on the paper
     svdDZkZD=svd(DZkZD)
+    
     #this is for ndim = 1 to work
     if (k != 1) {
       Lk=diag(svdDZkZD$d[1:k])
     } else {
       Lk = data.matrix(svdDZkZD$d[1])
     }
-    G = svdDZkZD$u
-
+    G = svdDZkZD$u[,1:k]
+    
     Gi = G[,1:k]
-
     Gi=Dksi%*%Gi%*%Lk # CA row coordinates (section 2 in the paper right below formula (1))
-  #  Gs = Gi%*%pseudoinverse(Lk)
-  #  ARC = Dk%*%(Gs*Gs)# cluster means absolute contributions
-    
-    Bstar=svdDZkZD$v
-    B=sqrt(n*q)*Dzhi %*% Bstar # as in eq. (8)
-    
-    Bns=B[,1:k]          
+    #inertia=sum(diag(Lk%*%Lk)) # explained inertia in k dimensions
+    Bstar=svdDZkZD$v[,1:k]
+    #sqrt(n*q)*
+    B=Dzhi %*% Bstar # as in eq. (8)
+    Bns = B[,1:k]
     Bi=Bstar[,1:k]           # attribute quantifications. Orthonormal
-    
-    #              
-    #  inertia = sum(t(Lk)%*% Lk) # explained inertia in k dimensions
-    
-    Yi=sqrt((n/q)) * MZD%*%Bi  # The coordinates for the subjects. as in eq. (10).
- #   Ys = Zki%*%chol2inv(chol(Dk))%*%t(Zki)%*%Yi%*%pseudoinverse(Lk)
-#    ARCy = Ys*Ys
-    
-    #######
-#    ARCb = Bi*Bi
-#    print(ARCb)
-#    print(apply(ARCb,2,sum))
-    #######
+    #sqrt((n/q))*
+    Yi= MZD%*%Bi  # The coordinates for the subjects. as in eq. (10).
     
     GDGbef=sum(diag(t(Gi) %*% Dk %*% Gi))   # Objective value before K means This is equivalent to formula (6), but then in the paper
     objbef=GDGbef
@@ -94,10 +83,11 @@ clusCA <- function(data,nclus,ndim,nstart=100,smartStart=NULL,gamma = FALSE, see
     improv=10
     iter=0   
     
-  #  objective=sum(diag((t(Yi)%*%Zki%*%chol2inv(chol(t(Zki)%*%Zki))%*%t(Zki)%*%Yi)))
-    while ((improv > 0.0001) && (iter<=maxiter)){
+    #  objective=sum(diag((t(Yi)%*%Zki%*%chol2inv(chol(t(Zki)%*%Zki))%*%t(Zki)%*%Yi)))
+    while ((improv > 0.0001) && (iter<maxiter)){
       iter = iter + 1
       outK = try(kmeans(Yi,centers=Gi,nstart=100),silent=T)
+  
       #empty clusters
       if(is.list(outK) == F){
         outK=EmptyKmeans(Yi,centers=Gi) 
@@ -106,15 +96,15 @@ clusCA <- function(data,nclus,ndim,nstart=100,smartStart=NULL,gamma = FALSE, see
       Zki=outK$cluster
       Gi=outK$centers
       Zki = tab.disjonctif(Zki)
-      
       Dk = t(Zki) %*% Zki        
       Dks = Dk^(.5)                  # New Dch weights
-      #Dksi = pseudoinverse(Dks)
-      Dksi = chol2inv(chol(Dks))
+      Dksi = pseudoinverse(Dks)
+      #Dksi = chol2inv(chol(Dks))
       #END Fixed B step: Given B, C is optimal.
       #Now: Fix C and recalculate B
-      DkZkZD=sqrt(n/q)*Dksi%*% t(Zki)%*%MZD # Make the new matrix for the SVD.
-      
+      #
+      #sqrt(n/q)
+      DkZkZD=Dksi%*% t(Zki)%*%MZD # Make the new matrix for the SVD.
       outDkZkZD=svd(DkZkZD)       # New SVD, CA analysis
       G=outDkZkZD$u
       Gi=G[,1:k]
@@ -126,60 +116,68 @@ clusCA <- function(data,nclus,ndim,nstart=100,smartStart=NULL,gamma = FALSE, see
       }
       
       Gi = Dksi %*% Gi %*% Lk
-      
-#      Gs = Gi%*%pseudoinverse(Lk)
-#      ARC = Dk%*%(Gs*Gs)# cluster means absolute contributions
+      Gs = Gi%*%pseudoinverse(Lk)
+  #    abscluscontr = Dk%*%(Gs*Gs)# cluster means absolute contributions
       
       Bstar=outDkZkZD$v
+      
       Bi=Bstar[,1:k]
-      B=sqrt(n*q)*Dzhi%*%Bi
+      #sqrt(n*q)
+      B=Dzhi%*%Bstar
       Bns=B[,1:k]
- 
-      Yi= sqrt((n/q)) * MZD %*% Bi # Subject coordinates
-#      Ys = Zki%*%chol2inv(chol(Dk))%*%t(Zki)%*%Yi%*%pseudoinverse(Lk)
-#      ARCy = Ys*Ys
+  #    absattcontr = Dz%*%Bns*Bns
+      
+  #    Bp = B[,1:(nclus-1)]%*%diag(outDkZkZD$d)[1:nclus-1,1:nclus-1]
+  #    B2= Dzhi%*%(Bp[,1:nclus-1]*Bp[,1:nclus-1]) 
+  #    totb= apply(B2,1,sum)
+  #    relattcontr = pseudoinverse(diag(totb))%*%B2
+      #sqrt((n/q)) *
+      Yi=  MZD %*% Bi # Subject coordinates
+   #   Ys = Zki%*%chol2inv(chol(Dk))%*%t(Zki)%*%Yi%*%pseudoinverse(Lk)
+  #    absobscontr = Ys*Ys
       
       improv=sum(diag(t(Gi)%*% t(Zki)%*%Zki%*%Gi))-objbef
       objbef=sum(diag(t(Gi) %*% t(Zki) %*% Zki %*% Gi))
-      #    print(improv)
       varsi=sum(diag(t(Gi)%*% Dk %*% Gi)) #no need to calc inside the loop
       
     }
-    #FIX: 16/09/2016, calculated outside the loop
-    # varsi=sum(diag(t(Gi)%*% Dk %*% Gi))
-    
-    # fvec = c(fvec, objbef)
-    #  print(fvec)
-    #  print(rs)
+  
     if (varsi > maxinert){ #gamma
       if (gamma == TRUE) { 
         distB = sum(diag(t(Bns)%*%  Bns))
         distG = sum(diag(t(Gi)%*% Gi))
         g = ((K/Q)* distB/distG)^.25
-  #      ARC = ARC
+   #     abscluscontr = abscluscontr
+   #    absattcontr = absattcontr
+   #     absobscontr = absobscontr
         
-  #      ARCy = ARCy
-  #      G2 = Dk%*%(G[,1:nclus-1]*G[,1:nclus-1])
-  #      totg = apply(G2,1,sum)
-  #      RPCG = pseudoinverse(diag(totg))%*%G2
+    #    G2 = Dk%*%(G[,1:nclus-1]*G[,1:nclus-1])
+    #    totg = apply(G2,1,sum)
+    #    relcluscontr = pseudoinverse(diag(totg))%*%G2
+        
+    #    relattcontr = relattcontr
+        
+    #    Y2 = Yi*Yi
+    #    toty = apply(Y2,1,sum)
+    #    relobscontr = chol2inv(chol(diag(toty)))%*%Y2
         
-  #      Y2 = Yi*Yi
-  #      toty = apply(Y2,1,sum)
-  #      RRCY = chol2inv(chol(diag(toty)))%*%Y2
         Bsol = (1/g)*Bns
         Gsol = g*Gi
         Ysol = g*Yi
       } else {
-   #     ARC = ARC
-  #      ARCy = ARCy
+    #    abscluscontr = abscluscontr
+    #    absobscontr = absobscontr
+    #    absattcontr = absattcontr
         
-   #     G2 = Dk%*%(G[,1:nclus-1]*G[,1:nclus-1])
-  #      totg = apply(G2,1,sum)
-    #    RPCG = pseudoinverse(diag(totg))%*%G2
+    #    G2 = Dk%*%(G[,1:nclus-1]*G[,1:nclus-1])
+    #    totg = apply(G2,1,sum)
+    #    relcluscontr = pseudoinverse(diag(totg))%*%G2
+        
+    #    relattcontr = relattcontr
         
     #    Y2 = Yi*Yi
     #    toty = apply(Y2,1,sum)
-    #    RRCY= chol2inv(chol(diag(toty)))%*%Y2
+    #    relobscontr= chol2inv(chol(diag(toty)))%*%Y2
         
         Bsol = Bns
         Gsol = Gi
@@ -194,6 +192,7 @@ clusCA <- function(data,nclus,ndim,nstart=100,smartStart=NULL,gamma = FALSE, see
   cluster = matrix(0,n,1)
   cluster[wone[,1]] = wone[,2]
   
+  
   ##reorder cluster membership according to cluster size
   #csize = round((table(cluster)/sum( table(cluster)))*100,digits=2)
   #aa = sort(csize,decreasing = TRUE)
@@ -207,15 +206,23 @@ clusCA <- function(data,nclus,ndim,nstart=100,smartStart=NULL,gamma = FALSE, see
   out$obscoord=data.frame(Ysol) # observations coordinates
   out$attcoord=data.frame(Bsol) # attributes coordinates
   out$centroid=data.frame(Gsol) # centroids
- # out$ARC=data.frame(ARC)
-#  out$ARCy=data.frame(ARCy)
-#  out$RPCG=data.frame(RPCG)
-#  out$RRCY=data.frame(RRCY)
+#  out$abscluscontr=data.frame(abscluscontr)
+#  out$absobscontr=data.frame(absobscontr)
+#  out$absattcontr=data.frame(absattcontr)
+
+#  out$relcluscontr=data.frame(relcluscontr)
+#  out$relattcontr=data.frame(relattcontr)
+#  out$relobscontr=data.frame(relobscontr)
   cluster = as.integer(cluster)
   names(cluster) = rownames(data) 
-  rownames(out$obscoord) = rownames(data)
-  rownames(out$attcoord) = colnames(Z) 
+#  rownames(out$obscoord) = rownames(data)
+#  rownames(out$absobscontr) = rownames(data)
+#  rownames(out$relobscontr) = rownames(data)
   
+#  rownames(out$attcoord) = colnames(Z) 
+#  rownames(out$absattcontr) = colnames(Z) 
+#  rownames(out$relattcontr) = colnames(Z) 
+
   out$cluster=cluster   # cluster membership
   out$criterion=maxinert # criterion
   #  out$iters=iters # number of iterations
